==> 1.8.tar.gz: harbour-sailotp/translations/harbour-sailotp-sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/pages/About.qml" line="75"/>
        <source>A Simple Sailfish OTP Generator
(RFC 6238/4226 compatible)</source>
        <translation>En enkel Sailfish OTP-generator
(RFC 6238/4226-kompatibel)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="84"/>
        <source>Copyright: Stefan Brand
License: BSD (3-clause)</source>
        <translation>Copyright: Stefan Brand
Licens: BSD (3-clause)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="110"/>
        <source>SailOTP uses the following third party libs:</source>
        <translation>SailOTP använder följande tredjeparts bibliotek:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="121"/>
        <source>Contributors:</source>
        <translation>Medarbetare:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="121"/>
        <source>Support</source>
        <translation>försörjning</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="132"/>
        <source>Translators:</source>
        <translation>Översättare:</translation>
    </message>
</context>
<context>
    <name>AddOTP</name>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="69"/>
        <source>Show QR-Code</source>
        <translation>Visa QR-kod</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="72"/>
        <location filename="../qml/pages/AddOTP.qml" line="85"/>
        <source>Can&apos;t create QR-Code from incomplete settings!</source>
        <translation>Kan inte skapa QR-kod från ofullständiga inställningar!</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="98"/>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="98"/>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="103"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="105"/>
        <source>Time-based (TOTP)</source>
        <translation>Tidsbaserad (TOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="106"/>
        <source>Counter-based (HOTP)</source>
        <translation>Räknarbaserad (HOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="107"/>
        <source>Steam Guard</source>
        <translation>Steam Guard</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="113"/>
        <source>Title</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="114"/>
        <source>Title for the OTP</source>
        <translation>Namn på OTP:n</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="126"/>
        <source>Secret (at least 16 characters)</source>
        <translation>Hemlighet (Minst 16 tecken)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="128"/>
        <source>Secret OTP Key</source>
        <translation>Hemlig OTP-nyckel</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="142"/>
        <source>Length</source>
        <translation>längd</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="144"/>
        <source>Length of the Token</source>
        <translation>Längden av token</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="156"/>
        <location filename="../qml/pages/AddOTP.qml" line="158"/>
        <source>Time Derivation (Seconds)</source>
        <translation>Tidsavvikelsen (sekunder)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="170"/>
        <source>Next Counter Value</source>
        <translation>Nästa räknarvärde</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="172"/>
        <source>Next Value of the Counter</source>
        <translation>Nästa värde på räknaren</translation>
    </message>
</context>
<context>
    <name>ExportPage</name>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="63"/>
        <source>File already exists, choose &quot;Overwrite existing&quot; to overwrite it.</source>
        <translation>Filen finns redan. Välj &quot;Skriv över befintlig&quot; för att skriva över den.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="72"/>
        <source>Given file does not exist!</source>
        <translation>Angiven fil finns inte!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Export</source>
        <translation>Exportera</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Import</source>
        <translation>Importera</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="114"/>
        <source>Filename</source>
        <translation>Filnamn</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to import</source>
        <translation>Fil att importera</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to export</source>
        <translation>Fil att exportera</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="128"/>
        <source>Overwrite existing</source>
        <translation>Skriv över befintlig</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="134"/>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="135"/>
        <source>Password for the file</source>
        <translation>Lösenord för filen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords don&apos;t match!</source>
        <translation>Lösenorden stämmer inte!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords match!</source>
        <translation>Lösenorden stämmer!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="149"/>
        <source>Repeated Password for the file</source>
        <translation>Upprepat lösenord för filen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="173"/>
        <source>Here you can Import Tokens from a file. Put in the file location and the password you used on export. Pull left to start the import.</source>
        <translation>Här kan du importera Token från en fil. Ange filens sökväg och lösenordet du angav vid exporten. Svep åt vänster för att starta importen.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>Here you can export Tokens to a file. The exported file will be encrypted with AES-256-CBC and Base64 encoded. Choose a strong password, the file will contain the secrets used to generate the Tokens for your accounts. Pull left to start the export.</source>
        <translation>Här kan du exportera Token till en fil. Den exporterade filen kommer att krypteras med AES-256-CBC och Base64. Välj ett starkt lösenord, filen kommer att innehålla hemligheterna som användes för att generera Token för ditt konto. Svep åt vänster för att starta exporten.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>To view the content of the export file outside of SailOTP use the following openssl command:</source>
        <translatorcomment>Translated using Google Translate</translatorcomment>
        <translation>Om du vill visa innehållet i exportfilen utanför SailOTP använder du följande openssl-kommando:</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="211"/>
        <source>Error writing to file </source>
        <translation>Fel vid skrivning till fil </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="213"/>
        <source>Token Database exported to </source>
        <translation>Token-databas exporterad till </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="216"/>
        <source>Could not encrypt tokens. Error: </source>
        <translation>Kunde inte kryptera token. Fel: </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="219"/>
        <source>Could not read tokens from Database</source>
        <translation>Kunde inte läsa in token från databasen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="230"/>
        <source>Tokens imported from </source>
        <translation>Token importerad från </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="235"/>
        <source>Unable to decrypt file, did you use the right password?</source>
        <translation>Kunde inte dekryptera filen. Angav du rätt lösenord?</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="238"/>
        <source>Could not read from file </source>
        <translation>Kunde inte läsa från fil </translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../qml/pages/MainView.qml" line="102"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="106"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="111"/>
        <source>Export / Import</source>
        <translation>Export / Import</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="115"/>
        <source>Add Token</source>
        <translation>Lägg till Token</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="129"/>
        <source>Nothing here</source>
        <translation>Inget här</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="130"/>
        <source>Pull down to add a OTP</source>
        <translation>Dra neråt för att lägga till en OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="165"/>
        <source>Deleting</source>
        <translation>Tar bort</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="186"/>
        <location filename="../qml/pages/MainView.qml" line="260"/>
        <source>Token for </source>
        <translation>Token för </translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="186"/>
        <location filename="../qml/pages/MainView.qml" line="260"/>
        <source> copied to clipboard</source>
        <translation> kopierad till urklipp</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="256"/>
        <source>Copy to Clipboard</source>
        <translation>Kopiera till Urklipp</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="264"/>
        <source>Show Token as QR-Code</source>
        <translation>Visa QR-kod</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="269"/>
        <source>Move up</source>
        <translation>Flytta upp</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="274"/>
        <source>Move down</source>
        <translation>Flytta ner</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="279"/>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="285"/>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
</context>
<context>
    <name>QRPage</name>
    <message>
        <location filename="../qml/pages/QRPage.qml" line="74"/>
        <source>Can&apos;t create QR-Code from an empty String</source>
        <translatorcomment>Google Translate</translatorcomment>
        <translation>Kan inte skapa QR-kod från en tom sträng</translation>
    </message>
</context>
<context>
    <name>ScanOTP</name>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="54"/>
        <source>Can&apos;t access temporary directory</source>
        <translation>Kan inte komma åt temp-mapp</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="64"/>
        <source>Add manually</source>
        <translation>Lägg till manuellt</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scan Code</source>
        <translation>Skanna kod</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scanning...</source>
        <translation>Skannar...</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="96"/>
        <source>No valid Token data found.</source>
        <translation>Ingen giltig Token-data hittades.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="137"/>
        <source>Tap the picture to start / stop scanning. Pull down to add Token manually.</source>
        <translation>Tryck på bilden för att starta / stoppa skanning. Dra neråt för att lägga till Token manuellt.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="50"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="52"/>
        <source>Behaviour</source>
        <translatorcomment>Google Translate</translatorcomment>
        <translation>Beteende</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Show Token as QR on Tap</source>
        <translatorcomment>Google Translate</translatorcomment>
        <translation>Visa Token som QR på kran</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="68"/>
        <source>Hide Tokens and Reveal on Tap</source>
        <translatorcomment>Google Translate</translatorcomment>
        <translation>Dölj tokens och avslöja på kranen</translation>
    </message>
</context>
</TS>

==> 1.8.1.tar.gz: harbour-sailotp/translations/harbour-sailotp-sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/pages/About.qml" line="75"/>
        <source>A Simple Sailfish OTP Generator
(RFC 6238/4226 compatible)</source>
        <translation>En enkel Sailfish OTP-generator
(RFC 6238/4226-kompatibel)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="84"/>
        <source>Copyright: Stefan Brand
License: BSD (3-clause)</source>
        <translation>Copyright: Stefan Brand
Licens: BSD (3-clause)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="110"/>
        <source>SailOTP uses the following third party libs:</source>
        <translation>SailOTP använder följande tredjeparts bibliotek:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="121"/>
        <source>Contributors:</source>
        <translation>Medarbetare:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="121"/>
        <source>Support</source>
        <translation>Support</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="132"/>
        <source>Translators:</source>
        <translation>Översättare:</translation>
    </message>
</context>
<context>
    <name>AddOTP</name>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="69"/>
        <source>Show QR-Code</source>
        <translation>Visa QR-kod</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="72"/>
        <location filename="../qml/pages/AddOTP.qml" line="85"/>
        <source>Can&apos;t create QR-Code from incomplete settings!</source>
        <translation>Kan inte skapa QR-kod från ofullständiga inställningar!</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="98"/>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="98"/>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="103"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="105"/>
        <source>Time-based (TOTP)</source>
        <translation>Tidsbaserad (TOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="106"/>
        <source>Counter-based (HOTP)</source>
        <translation>Räknarbaserad (HOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="107"/>
        <source>Steam Guard</source>
        <translation>Steam Guard</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="113"/>
        <source>Title</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="114"/>
        <source>Title for the OTP</source>
        <translation>Namn på OTP:n</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="126"/>
        <source>Secret (at least 16 characters)</source>
        <translation>Hemlighet (Minst 16 tecken)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="128"/>
        <source>Secret OTP Key</source>
        <translation>Hemlig OTP-nyckel</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="142"/>
        <source>Length</source>
        <translation>Längd</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="144"/>
        <source>Length of the Token</source>
        <translation>Längd på token</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="156"/>
        <location filename="../qml/pages/AddOTP.qml" line="158"/>
        <source>Time Derivation (Seconds)</source>
        <translation>Tidsavvikelse (sekunder)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="170"/>
        <source>Next Counter Value</source>
        <translation>Nästa räknarvärde</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="172"/>
        <source>Next Value of the Counter</source>
        <translation>Nästa värde på räknaren</translation>
    </message>
</context>
<context>
    <name>ExportPage</name>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="63"/>
        <source>File already exists, choose &quot;Overwrite existing&quot; to overwrite it.</source>
        <translation>Filen finns redan. Välj &quot;Skriv över befintlig&quot; för att skriva över den.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="72"/>
        <source>Given file does not exist!</source>
        <translation>Angiven fil finns inte!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Export</source>
        <translation>Exportera</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Import</source>
        <translation>Importera</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="114"/>
        <source>Filename</source>
        <translation>Filnamn</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to import</source>
        <translation>Fil att importera</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to export</source>
        <translation>Fil att exportera</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="128"/>
        <source>Overwrite existing</source>
        <translation>Skriv över befintlig</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="134"/>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="135"/>
        <source>Password for the file</source>
        <translation>Lösenord för filen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords don&apos;t match!</source>
        <translation>Lösenorden stämmer inte!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords match!</source>
        <translation>Lösenorden stämmer!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="149"/>
        <source>Repeated Password for the file</source>
        <translation>Upprepat lösenordet för filen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="173"/>
        <source>Here you can Import Tokens from a file. Put in the file location and the password you used on export. Pull left to start the import.</source>
        <translation>Här kan du importera Token från en fil. Ange filens sökväg och lösenordet du angav vid exporten. Svep åt vänster för att starta importen.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>Here you can export Tokens to a file. The exported file will be encrypted with AES-256-CBC and Base64 encoded. Choose a strong password, the file will contain the secrets used to generate the Tokens for your accounts. Pull left to start the export.</source>
        <translation>Här kan du exportera Token till en fil. Den exporterade filen kommer att krypteras med AES-256-CBC och Base64. Välj ett starkt lösenord, filen kommer att innehålla hemligheterna som användes för att generera Token för ditt konto. Svep åt vänster för att starta exporten.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>To view the content of the export file outside of SailOTP use the following openssl command:</source>
        <translation>För att visa innehållet i exportfilen utanför SailOTP, använder du följande openssl-kommando:</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="211"/>
        <source>Error writing to file </source>
        <translation>Fel vid skrivning till fil </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="213"/>
        <source>Token Database exported to </source>
        <translation>Token-databas exporterad till </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="216"/>
        <source>Could not encrypt tokens. Error: </source>
        <translation>Kunde inte kryptera token. Fel: </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="219"/>
        <source>Could not read tokens from Database</source>
        <translation>Kunde inte läsa token från databasen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="230"/>
        <source>Tokens imported from </source>
        <translation>Token importerade från </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="235"/>
        <source>Unable to decrypt file, did you use the right password?</source>
        <translation>Kunde inte dekryptera filen. Angav du rätt lösenord?</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="238"/>
        <source>Could not read from file </source>
        <translation>Kunde inte läsa från fil </translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../qml/pages/MainView.qml" line="102"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="106"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="111"/>
        <source>Export / Import</source>
        <translation>Export / Import</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="115"/>
        <source>Add Token</source>
        <translation>Lägg till Token</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="129"/>
        <source>Nothing here</source>
        <translation>Inget här</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="130"/>
        <source>Pull down to add a OTP</source>
        <translation>Dra neråt för att lägga till en OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="165"/>
        <source>Deleting</source>
        <translation>Tar bort</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="186"/>
        <location filename="../qml/pages/MainView.qml" line="260"/>
        <source>Token for </source>
        <translation>Token för </translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="186"/>
        <location filename="../qml/pages/MainView.qml" line="260"/>
        <source> copied to clipboard</source>
        <translation> kopierad till urklipp</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="256"/>
        <source>Copy to Clipboard</source>
        <translation>Kopiera till Urklipp</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="264"/>
        <source>Show Token as QR-Code</source>
        <translation>Visa token som QR-kod</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="269"/>
        <source>Move up</source>
        <translation>Flytta upp</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="274"/>
        <source>Move down</source>
        <translation>Flytta ner</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="279"/>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="285"/>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
</context>
<context>
    <name>QRPage</name>
    <message>
        <location filename="../qml/pages/QRPage.qml" line="74"/>
        <source>Can&apos;t create QR-Code from an empty String</source>
        <translation>Kan inte skapa QR-kod från en tom sträng</translation>
    </message>
</context>
<context>
    <name>ScanOTP</name>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="54"/>
        <source>Can&apos;t access temporary directory</source>
        <translation>Kan inte komma åt temp-mappen</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="64"/>
        <source>Add manually</source>
        <translation>Lägg till manuellt</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scan Code</source>
        <translation>Skanna kod</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scanning...</source>
        <translation>Skannar...</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="96"/>
        <source>No valid Token data found.</source>
        <translation>Ingen giltig Token-data hittades.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="137"/>
        <source>Tap the picture to start / stop scanning. Pull down to add Token manually.</source>
        <translation>Tryck på bilden för att starta / stoppa skanning. Dra neråt för att lägga till Token manuellt.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="50"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="52"/>
        <source>Behaviour</source>
        <translation>Beteende</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Show Token as QR on Tap</source>
        <translation>Visa token som QR-kod, vid tryck</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="68"/>
        <source>Hide Tokens and Reveal on Tap</source>
        <translation>Dölj token och visa vid tryck</translation>
    </message>
</context>
</TS>
